View Source Bind (bind v0.11.0)

Summary

Functions

Merges additional filters with existing query params.

Maps over query parameters, letting you transform values by pattern matching field names.

Maps over query parameters with error handling. Returns {:ok, mapped_params} on success or {:error, reason} on failure.

Builds an Ecto query for the given schema based on the provided parameters.

Functions

Link to this function

filter(query_string, filters)

Merges additional filters with existing query params.

Link to this function

map(query_string, field_mappers)

Maps over query parameters, letting you transform values by pattern matching field names.

Link to this function

map_safe(query_string, field_mappers)

Maps over query parameters with error handling. Returns {:ok, mapped_params} on success or {:error, reason} on failure.

Link to this function

query(params, schema, opts \\ [])

Builds an Ecto query for the given schema based on the provided parameters.